@@ -1,12 +1,12 @@
-from .Protocol import Protocol
-from .Processor import Processor
-from .States import MOESIState as State
-from .Operations import MSIOps as Ops
+from pyceg.Multiprocessor.Protocol import Protocol
+from pyceg.Multiprocessor.Processor import Processor
+from pyceg.Multiprocessor.States import MOESIState as State
+from pyceg.Multiprocessor.Operations import MSIOps as Ops
 
-from .VI_Write_Through import VI
-from .MSI import MSI
-from .MESI import MESI
-from .MOESI import MOESI
+from pyceg.Multiprocessor.VI_Write_Through import VI
+from pyceg.Multiprocessor.MSI import MSI
+from pyceg.Multiprocessor.MESI import MESI
+from pyceg.Multiprocessor.MOESI import MOESI
 
 protocols = {"VI": VI, "MSI": MSI, "MESI": MESI, "MOESI": MESI}
 
