@@ -1,13 +1,9 @@
 # Basic MESI Write-back Invalidation Protocol
 
 
-from .Protocol import Protocol
-from .States import MESIState as State
-from .Operations import MSIOps as Ops
-
-
-# from importlib import import_module
-# Protocol = getattr(import_module('Protocol'), 'Protocol')
+from pyceg.Multiprocessor.Protocol import Protocol
+from pyceg.Multiprocessor.States import MESIState as State
+from pyceg.Multiprocessor.Operations import MSIOps as Ops
 
 
 ###################
