@@ -1,7 +1,7 @@
+from pyceg.Multiprocessor.Processor import Processor
+from pyceg.Multiprocessor.Operations import MESIOps as Ops
+from pyceg.Multiprocessor.States import MESIState as State
 from tabulate import tabulate
-from .Processor import Processor
-from .Operations import MESIOps as Ops
-from .States import MESIState as State
 
 
 class Protocol:
