@@ -1,7 +1,7 @@
 #  Two-state write-through write invalidate protocol
-from .Protocol import Protocol
-from .States import VIState as State
-from .Operations import VIOps as Ops
+from pyceg.Multiprocessor.Protocol import Protocol
+from pyceg.Multiprocessor.States import VIState as State
+from pyceg.Multiprocessor.Operations import VIOps as Ops
 
 
 ######################################
